<?php


if ( !function_exists( 'uoncorp_google_fonts_url' ) ) {
  /*
   * Register Google Font Family
   */
  function uoncorp_google_fonts_url() {

    wp_enqueue_style( 'uoncorp_google_fonts', 'https://fonts.googleapis.com/css?family=Poppins:400,600,800', false );
    wp_enqueue_style( 'uoncorp_google_fonts', 'https://fonts.googleapis.com/css?family=Playfair+Display:400,800', false );
  }

  add_action( 'wp_enqueue_scripts', 'uoncorp_google_fonts_url' );

}



if ( ! function_exists( 'uoncorp_enqueue_styles_and_scripts' ) ) {
	/**
	 * This function enqueues the required css and js files.
	 *
	 * @return void
	 */
	function uoncorp_enqueue_styles_and_scripts() {
		/**
		 * Enqueue css files.
		 */
		wp_enqueue_style( 'uoncorp-bundle', get_template_directory_uri() . '/css/bundle.min.css' );
		wp_enqueue_style( 'bootsrap', get_template_directory_uri() . '/css/bootstrap.min.css' );
		wp_enqueue_style( 'uoncorp-main-style', get_template_directory_uri() . '/css/style.css' );
		wp_enqueue_style( 'uoncorp-stylesheet', get_stylesheet_uri() );
		wp_add_inline_style( 'uoncorp-stylesheet', uoncorp_dynamic_css() );

		/**
		 * Enqueue javascript files.
		 */

		wp_enqueue_script( 'comments', get_template_directory_uri() . '/js/comments.js', array(), false, false );
		wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'uoncorp-bundle', get_template_directory_uri() . '/js/bundle.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'uoncorp-scripts', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ), false, true );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		$data = array(
			'pre_loader_typewriter' => [],
			'audio_source' => '',
			'enable_sound_bar' => false
		);

		if( uoncorp_get_option( 'enable_preloader' ) ) {
			$typewriter_text = [];
			$text_rotater = uoncorp_get_option( 'pre_loader_text_rotater' );
			if( $text_rotater ) {
				foreach ( $text_rotater as $rotater ) {
					$typewriter_text[] = esc_html( $rotater['title'] );
				}
			}
			$data['pre_loader_typewriter'] = $typewriter_text;
		}
		
		$comment_data = array(
			'name'      => esc_html__( 'Name is required', 'uoncorp' ),
			'email'     => esc_html__( 'Email is required', 'uoncorp' ),
			'comment'   => esc_html__( 'Comment is required', 'uoncorp' ),

		);

		wp_localize_script( 'uoncorp-scripts', 'data', $data );
		wp_localize_script( 'comments', 'comment_data', $comment_data );
	}

	add_action( 'wp_enqueue_scripts', 'uoncorp_enqueue_styles_and_scripts', 10 );
}

if( !function_exists( 'uoncorp_dynamic_css' ) ) {
	function uoncorp_dynamic_css() {

		$styles = '';
		if( uoncorp_get_option( 'logo_height' ) ) {
			$logo_height = str_replace(' ', '', uoncorp_get_option( 'logo_height' ) );
			$logo_height = str_replace('px', '', $logo_height);
			$styles .= "
				.navbar .container .logo a img{
					height: {$logo_height}px;
				}
			";
		}
		if( uoncorp_get_option( 'enable_dynamic_color' ) ) {

			$body_color = ( uoncorp_get_option( 'body_color' ) ) ? uoncorp_get_option( 'body_color' ) : '#33a16e';
			$theme_color1 = ( uoncorp_get_option( 'theme_color1' ) ) ? uoncorp_get_option( 'theme_color1' ) : '#131314';
			$theme_color2 = ( uoncorp_get_option( 'theme_color2' ) ) ? uoncorp_get_option( 'theme_color2' ) : '#131314';
			$theme_color3 = ( uoncorp_get_option( 'theme_color3' ) ) ? uoncorp_get_option( 'theme_color3' ) : '#131314';

			$styles .= "
				
				
				
				:root {
  --color-body: {$body_color}; 
  --color-one: {$theme_color1}; 
  --color-two: {$theme_color2}; 
  --color-three: {$theme_color3}; 
}
				
				
				
				
			";
		}

		return $styles;
	}
}

add_action( 'init', 'uoncorp_dynamic_css' );
add_action(
    'after_setup_theme',
    function() {
        add_theme_support( 'html5', [ 'script', 'style' ] );
    }
);